@@ -22,17 +22,17 @@
 
 #include "kglobalaccel.h"
 #include "kglobalaccel_p.h"
+#include "kglobalaccel_debug.h"
 
 #include <memory>
 
 #include <QAction>
 #include <QActionEvent>
-#include <QDebug>
 #include <QGuiApplication>
 #include <QMessageBox>
 #include <QPushButton>
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusMetaType>
+#include <QDBusInterface>
+#include <QDBusMetaType>
 #include <config-kglobalaccel.h>
 #if HAVE_X11
 #include <QX11Info>
@@ -41,8 +41,11 @@
 org::kde::kglobalaccel::Component *KGlobalAccelPrivate::getComponent(const QString &componentUnique, bool remember = false)
 {
     // Check if we already have this component
-    if (components.contains(componentUnique)) {
-        return components[componentUnique];
+    {
+        auto component = components.value(componentUnique);
+        if (component) {
+            return component;
+        }
     }
 
     // Connect to the kglobalaccel daemon
@@ -51,8 +54,8 @@ org::kde::kglobalaccel::Component *KGlobalAccelPrivate::getComponent(const QStri
         QStringLiteral("/kglobalaccel"),
         QDBusConnection::sessionBus());
     if (!kglobalaccel.isValid()) {
-        qDebug() << "Failed to connect to the kglobalaccel daemon" << QDBusConnection::sessionBus().lastError();
-        return NULL;
+        qCDebug(KGLOBALACCEL_LOG) << "Failed to connect to the kglobalaccel daemon" << QDBusConnection::sessionBus().lastError();
+        return nullptr;
     }
 
     // Get the path for our component. We have to do that because
@@ -62,12 +65,12 @@ org::kde::kglobalaccel::Component *KGlobalAccelPrivate::getComponent(const QStri
 
         if (reply.error().name() == QLatin1String("org.kde.kglobalaccel.NoSuchComponent")) {
             // No problem. The component doesn't exists. That's normal
-            return NULL;
+            return nullptr;
         }
 
         // An unknown error.
-        qDebug() << "Failed to get dbus path for component " << componentUnique << reply.error();
-        return NULL;
+        qCDebug(KGLOBALACCEL_LOG) << "Failed to get dbus path for component " << componentUnique << reply.error();
+        return nullptr;
     }
 
     // Now get the component
@@ -79,8 +82,8 @@ org::kde::kglobalaccel::Component *KGlobalAccelPrivate::getComponent(const QStri
 
     // No component no cleaning
     if (!component->isValid()) {
-        qDebug() << "Failed to get component" << componentUnique << QDBusConnection::sessionBus().lastError();
-        return NULL;
+        qCDebug(KGLOBALACCEL_LOG) << "Failed to get component" << componentUnique << QDBusConnection::sessionBus().lastError();
+        return nullptr;
     }
 
     if (remember) {
@@ -117,7 +120,7 @@ KGlobalAccelPrivate::KGlobalAccelPrivate(KGlobalAccel *q)
     enabled(true),
 #endif
     q(q),
-    m_iface(Q_NULLPTR)
+    m_iface(nullptr)
 {
     m_watcher = new QDBusServiceWatcher(serviceName(),
             QDBusConnection::sessionBus(),
@@ -305,8 +308,6 @@ void KGlobalAccelPrivate::updateGlobalShortcut(/*const would be better*/QAction*
     }
 
     QStringList actionId = makeActionId(action);
-    const QList<QKeySequence> activeShortcut = actionShortcuts.value(action);
-    const QList<QKeySequence> defaultShortcut = actionDefaultShortcuts.value(action);
 
     uint setterFlags = 0;
     if (globalFlags & NoAutoloading) {
@@ -314,6 +315,7 @@ void KGlobalAccelPrivate::updateGlobalShortcut(/*const would be better*/QAction*
     }
 
     if (actionFlags & ActiveShortcut) {
+        const QList<QKeySequence> activeShortcut = actionShortcuts.value(action);
         bool isConfigurationAction = action->property("isConfigurationAction").toBool();
         uint activeSetterFlags = setterFlags;
 
@@ -323,7 +325,7 @@ void KGlobalAccelPrivate::updateGlobalShortcut(/*const would be better*/QAction*
         }
 
         // Sets the shortcut, returns the active/real keys
-        const QList<int> result = iface()->setShortcut(
+        const auto result = iface()->setShortcut(
                                       actionId,
                                       intListFromShortcut(activeShortcut),
                                       activeSetterFlags);
@@ -356,6 +358,7 @@ void KGlobalAccelPrivate::updateGlobalShortcut(/*const would be better*/QAction*
     }
 
     if (actionFlags & DefaultShortcut) {
+        const QList<QKeySequence> defaultShortcut = actionDefaultShortcuts.value(action);
         iface()->setShortcut(actionId, intListFromShortcut(defaultShortcut),
                           setterFlags | IsDefault);
     }
@@ -432,7 +435,7 @@ void KGlobalAccelPrivate::_k_invokeAction(
     const QString &actionUnique,
     qlonglong timestamp)
 {
-    QAction *action = 0;
+    QAction *action = nullptr;
     QList<QAction *> candidates = nameToAction.values(actionUnique);
     Q_FOREACH (QAction *const a, candidates) {
         if (componentUniqueForAction(a) == componentUnique) {
@@ -486,7 +489,7 @@ void KGlobalAccelPrivate::_k_serviceOwnerChanged(const QString &name, const QStr
     Q_UNUSED(oldOwner);
     if (name == QLatin1String("org.kde.kglobalaccel") && !newOwner.isEmpty()) {
         // kglobalaccel was restarted
-        qDebug() << "detected kglobalaccel restarting, re-registering all shortcut keys";
+        qCDebug(KGLOBALACCEL_LOG) << "detected kglobalaccel restarting, re-registering all shortcut keys";
         reRegisterAll();
     }
 }
@@ -714,7 +717,7 @@ bool KGlobalAccel::eventFilter(QObject *watched, QEvent *event)
 bool KGlobalAccel::setGlobalShortcut(QAction *action, const QList<QKeySequence> &shortcut)
 {
     KGlobalAccel *g = KGlobalAccel::self();
-    return g->setShortcut(action, shortcut) && g->setDefaultShortcut(action, shortcut);
+    return g->d->setShortcutWithDefault(action, shortcut, Autoloading);
 }
 
 bool KGlobalAccel::setGlobalShortcut(QAction *action, const QKeySequence &shortcut)
@@ -722,5 +725,21 @@ bool KGlobalAccel::setGlobalShortcut(QAction *action, const QKeySequence &shortc
     return KGlobalAccel::setGlobalShortcut(action, QList<QKeySequence>() << shortcut);
 }
 
+bool KGlobalAccelPrivate::setShortcutWithDefault(QAction* action, const QList<QKeySequence>& shortcut, KGlobalAccel::GlobalShortcutLoading loadFlag)
+{
+    if (checkGarbageKeycode(shortcut)) {
+        return false;
+    }
+
+    if (!doRegister(action)) {
+        return false;
+    }
+
+    actionDefaultShortcuts.insert(action, shortcut);
+    actionShortcuts.insert(action, shortcut);
+    updateGlobalShortcut(action, KGlobalAccelPrivate::DefaultShortcut | KGlobalAccelPrivate::ActiveShortcut, loadFlag);
+    return true;
+}
+
 #include "moc_kglobalaccel.cpp"
 
